@@ -3,7 +3,9 @@ package Amazon::API::Signature4;
 use strict;
 use warnings;
 
-use parent qw{ AWS::Signature4 };
+use parent qw/AWS::Signature4/;
+
+our $VERSION = '1.1.9'; $VERSION=~s/\-.*$//;
 
 sub new {
   my $class = shift;
